@@ -482,7 +482,7 @@ having some automated conveniences and defaults.
                     results.append(sorted(cursor))
                 elif perpage:
                     total = (page - 1) * perpage
-                    cursor = collection.find(query, fields, **kwargs)
+                    cursor = collection.find(query, projection=fields, **kwargs)
                     results.append(cursor.sort([(key, sort)]).skip(total).limit(perpage))
                 elif limit:
                     if any((query, after, before)):
@@ -516,13 +516,13 @@ having some automated conveniences and defaults.
                             cursor = len(await collection.find(query, fields, **kwargs).sort([(key, sort)]).to_list(limit))
                         results.append(cursor)
                     else:
-                        cursor = collection.find(query, fields, **kwargs).sort([(key, sort)]).limit(limit)
+                        cursor = collection.find(query, projection=fields, **kwargs).sort([(key, sort)]).limit(limit)
                         results.append(cursor)
                 elif one:
-                    val = await collection.find_one(query, fields, **kwargs)
+                    val = await collection.find_one(query, projection=fields, sort=[(key, sort)], **kwargs)
                     results.append(val if val else empty)
                 else:
-                    cursor = collection.find(query, fields, **kwargs).sort([(key, sort)])
+                    cursor = collection.find(query, projection=fields, **kwargs).sort([(key, sort)])
                     results.append(cursor)
             elif search:
                 try:
@@ -579,15 +579,23 @@ having some automated conveniences and defaults.
             raise TypeError("invalid record type '{}' provided".format(type(record_or_records)))
 
     async def PUT(self, collection, record_or_records:typing.Union[typing.List, typing.Dict]):
+        """
+            creates or replaces record(s) with exact _id provided, _id is required with record object(s)
+
+            returns original document, if replaced
+        """
         db = self.get_default_database()
         collection = collection or self._DEFAULT_COLLECTION
         assert collection, "collection must be of type str"
         collection = db[collection]
 
         if isinstance(record_or_records, (list, tuple)):
-            return await collection.insert_many(record_or_records)
+            assert all([ record.get("_id", None) for record in record_or_records ]), "not all records provided contained an _id"
+            return await collection.insert_many(record_or_records, ordered=False)
         elif isinstance(record_or_records, dict):
-            return await collection.insert_one(record_or_records)
+            assert record_or_records.get("_id", None), "no _id provided"
+            query = {"_id": record_or_records["_id"]}
+            return await collection.find_one_and_replace(query, record_or_records, upsert=True)
         else:
             raise TypeError("invalid record type '{}' provided".format(type(record_or_records)))
 
